@@ -88,6 +88,7 @@ SCHEDULED_RULE = "scheduled_rule"
 RULE = "rule"
 
 RESERVED_FUNCTIONS = [
+    "alert_context",
     "dedup",
     "title",
     "description",
@@ -678,8 +679,12 @@ def test_analysis(args: argparse.Namespace) -> Tuple[int, list]:
         "." + DATA_MODEL_LOCATION,
     ):
         absolute_dir_path = os.path.abspath(os.path.join(args.path, directory))
+        absolute_helper_path = os.path.abspath(directory)
+
         if os.path.exists(absolute_dir_path):
             search_directories.append(absolute_dir_path)
+        if os.path.exists(absolute_helper_path):
+            search_directories.append(absolute_helper_path)
 
     # First classify each file, always include globals and data models location
     specs, invalid_specs = classify_analysis(list(load_analysis_specs(search_directories)))
@@ -808,6 +813,8 @@ def setup_run_tests(
             analysis_funcs["run"] = module.policy
         elif analysis_type in [RULE, SCHEDULED_RULE]:
             analysis_funcs["run"] = module.rule
+            if "alert_context" in dir(module):
+                analysis_funcs["alert_context"] = module.alert_context
             if "dedup" in dir(module):
                 analysis_funcs["dedup"] = module.dedup
             if "title" in dir(module):
@@ -1189,6 +1196,8 @@ def validate_outputs(function_name: str, function_output: Any) -> Tuple[bool, An
                 f"Expected [{function_name}] to be any of the following: "
                 f"{str(VALID_SEVERITIES)}, got [{str(function_output)}] instead."
             )
+    elif function_name == "alert_context":
+        is_valid = isinstance(function_output, dict)
     elif function_name == "destinations":
         # Type checking for destinations
         if isinstance(function_output, list):
@@ -1291,7 +1300,7 @@ def setup_parser() -> argparse.ArgumentParser:
         + "managing Panther policies and rules.",
         prog="panther_analysis_tool",
     )
-    parser.add_argument("--version", action="version", version="panther_analysis_tool 0.7.3")
+    parser.add_argument("--version", action="version", version="panther_analysis_tool 0.7.4")
     parser.add_argument("--debug", action="store_true", dest="debug")
     subparsers = parser.add_subparsers()
 
